SequenceFeature

Struct SequenceFeature 

#[non_exhaustive]
pub struct SequenceFeature { pub identity: Resource, pub identified: IdentifiedData, pub feature: FeatureData, pub locations: Vec<Resource>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
identity: Resourceidentified: IdentifiedDatafeature: FeatureDatalocations: Vec<Resource>

Implementations

Source

impl SequenceFeature

pub fn new( parent: &Resource, display_id: impl TryInto<DisplayId, Error = BuildError>, locations: impl IntoIterator<Item = Resource>, ) -> Result<Self, BuildError>

pub fn builder( parent: &Resource, display_id: impl TryInto<DisplayId, Error = BuildError>, ) -> Result<SequenceFeatureBuilder, BuildError>

Source

impl SequenceFeature

pub fn parent_component<'a>(&self, doc: &'a Document) -> Option<&'a Component>

Returns the Component that owns this feature via sbol:hasFeature, or None if no enclosing component is in the document. SBOL features must belong to exactly one component, so a Some result is unambiguous.

Source

impl SequenceFeature

pub fn locations<'doc>( &'doc self, doc: &'doc Document, ) -> impl Iterator<Item = LocationRef<'doc>> + 'doc

Iterate over this SequenceFeature’s child Locations.