pub struct UnknownRule {
pub rule: String,
}Expand description
Returned when a per-rule override targets a rule that is not in the catalog — almost always a typo at the call site.
Fields
rule: StringTrait Implementations
Sourceimpl Clone for UnknownRule
impl Clone for UnknownRule
Sourcefn clone(&self) -> UnknownRule
fn clone(&self) -> UnknownRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnknownRule
impl Debug for UnknownRule
Sourceimpl Display for UnknownRule
impl Display for UnknownRule
Sourceimpl Error for UnknownRule
impl Error for UnknownRule
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for UnknownRule
impl PartialEq for UnknownRule
Sourcefn eq(&self, other: &UnknownRule) -> bool
fn eq(&self, other: &UnknownRule) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UnknownRule
impl StructuralPartialEq for UnknownRule